
'''

Simple module for logging

'''


from pyloggering.pyloggering import Utility, Log


utility = Utility()
log = Log(utility)

def create_file(name,location,type):

    utility.create_file(name,location,type)














        
